@@ -23,6 +23,21 @@ from .training import AzureCloudTrainingContext, AzureLocalTrainingContext
 
 class AzureBackend(AbstractBackend):
 
+    def parse_azureml_exception(self, e):
+        """
+        Extracts error message from AzureMLException and
+        returns a BackendException.
+
+        :param azureml._common.exceptions.AzureMLException e:
+        :rtype: AbstractBackend.BackendException
+        """
+        msg = str(e)
+        matches = re.findall(r'"message":"([^"]+)"', msg)
+        if matches:
+            return self.BackendException(matches[0])
+        else:
+            return self.BackendException(msg)
+
     @cached_property
     def _credential(self):
         """
@@ -34,7 +49,10 @@ class AzureBackend(AbstractBackend):
         """
         """
         subscription_client = SubscriptionClient(self._credential)
-        return list(subscription_client.subscriptions.list())
+        try:
+            return list(subscription_client.subscriptions.list())
+        except azureml._common.exceptions.AzureMLException as e:
+            raise self.parse_azureml_exception(e)
 
     def get_available_resource_groups(self, subscription_id):
         """
@@ -42,7 +60,10 @@ class AzureBackend(AbstractBackend):
         """
         resource_client = ResourceManagementClient(
             self._credential, subscription_id)
-        return list(resource_client.resource_groups.list())
+        try:
+            return list(resource_client.resource_groups.list())
+        except azureml._common.exceptions.AzureMLException as e:
+            raise self.parse_azureml_exception(e)
 
     # -- Workspaces ----------------------------------------------------------
 
@@ -52,11 +73,14 @@ class AzureBackend(AbstractBackend):
         :param str resource_group:
         :rtype: list[Workspace]
         """
-        workspaces_mapped = Workspace.list(
-            auth=self._credential,
-            subscription_id=subscription_id,
-            resource_group=resource_group,
-        )
+        try:
+            workspaces_mapped = Workspace.list(
+                auth=self._credential,
+                subscription_id=subscription_id,
+                resource_group=resource_group,
+            )
+        except azureml._common.exceptions.AzureMLException as e:
+            raise self.parse_azureml_exception(e)
 
         workspaces = []
 
@@ -85,12 +109,15 @@ class AzureBackend(AbstractBackend):
         :param str name:
         :rtype: Workspace
         """
-        return Workspace.get(
-            auth=self._credential,
-            subscription_id=subscription_id,
-            resource_group=resource_group,
-            name=name,
-        )
+        try:
+            return Workspace.get(
+                auth=self._credential,
+                subscription_id=subscription_id,
+                resource_group=resource_group,
+                name=name,
+            )
+        except azureml._common.exceptions.AzureMLException as e:
+            raise self.parse_azureml_exception(e)
 
     # -- Compute clusters ----------------------------------------------------
 
@@ -98,14 +125,20 @@ class AzureBackend(AbstractBackend):
         """
         :param Workspace workspace:
         """
-        return AmlCompute.list(workspace=workspace)
+        try:
+            return AmlCompute.list(workspace=workspace)
+        except azureml._common.exceptions.AzureMLException as e:
+            raise self.parse_azureml_exception(e)
 
     def get_available_vm_sizes(self, workspace):
         """
         :param Workspace workspace:
         :rtype: typing.List[str]
         """
-        return AmlCompute.supported_vmsizes(workspace=workspace)
+        try:
+            return AmlCompute.supported_vmsizes(workspace=workspace)
+        except azureml._common.exceptions.AzureMLException as e:
+            raise self.parse_azureml_exception(e)
 
     def get_suggested_vm_size(self, compute_type):
         """
@@ -140,11 +173,8 @@ class AzureBackend(AbstractBackend):
             ComputeTarget \
                 .create(workspace, name, compute_config) \
                 .wait_for_completion(show_output=False)
-        except azureml.exceptions._azureml_exception.ComputeTargetException as e:
-            # It seems impossible to get the error message without
-            # getting the rest of the API's raw HTTP response...
-            message = re.findall('"message":"([^"]+)"', str(e))[0]
-            raise self.BackendException(message)
+        except azureml._common.exceptions.AzureMLException as e:
+            raise self.parse_azureml_exception(e)
 
     # -- Contexts ------------------------------------------------------------
 
@@ -153,7 +183,7 @@ class AzureBackend(AbstractBackend):
         :param bool force_download:
         :rtype: energinetml.core.AbstractTrainingContext
         """
-        return AzureLocalTrainingContext(force_download)
+        return AzureLocalTrainingContext(self, force_download)
 
     def get_cloud_training_context(self):
         """
@@ -194,12 +224,17 @@ class AzureBackend(AbstractBackend):
         )
 
         with model.temporary_folder() as path:
-            run = experiment.submit(ScriptRunConfig(
+            config = ScriptRunConfig(
                 source_directory=path,
                 script=model.SCRIPT_FILE_NAME,
                 arguments=['model', 'train', '--cloud-mode'] + list(params),
                 run_config=compute_config,
-            ))
+            )
+
+            try:
+                run = experiment.submit(config)
+            except azureml._common.exceptions.AzureMLException as e:
+                raise self.parse_azureml_exception(e)
 
             return AzureSubmitContext(model, run)
 
@@ -207,12 +242,15 @@ class AzureBackend(AbstractBackend):
         """
         :rtype: Model
         """
-        asset = Model._create_asset(
-            workspace.service_context, model_path, model_name, None)
+        try:
+            asset = Model._create_asset(
+                workspace.service_context, model_path, model_name, None)
 
-        return Model._register_with_asset(
-            workspace=workspace,
-            model_name=model_name,
-            asset_id=asset.id,
-            **kwargs,
-        )
+            return Model._register_with_asset(
+                workspace=workspace,
+                model_name=model_name,
+                asset_id=asset.id,
+                **kwargs,
+            )
+        except azureml._common.exceptions.AzureMLException as e:
+            raise self.parse_azureml_exception(e)
