@@ -1,11 +1,10 @@
 import click
 import click_spinner
 
-from energinetml.core.model import Model, TrainedModel
+from energinetml.core.model import TrainedModel
 from energinetml.backend import default_backend as backend
 from energinetml.settings import PACKAGE_VERSION, PACKAGE_NAME
-
-from .utils import discover_model
+from energinetml.cli.utils import discover_model
 
 
 # -- CLI Command -------------------------------------------------------------
@@ -32,7 +31,7 @@ def train(parameters, cloud_mode, force_download, seed, model):
     :param bool cloud_mode:
     :param bool force_download:
     :param str seed:
-    :param Model model:
+    :param energinetml.Model model:
     """
 
     # -- Train Parameters ----------------------------------------------------
