@@ -5,6 +5,9 @@ from energinetml.core.project import Project
 from energinetml.backend import default_backend as backend
 from energinetml.settings import DEFAULT_LOCATION, COMMAND_NAME
 
+from .add_gitignore import add_gitignore_lines
+from .add_pipelines import add_pipeline_files
+
 
 # Constants  TODO Move to Project class?
 PROJECT_FILES = ('project.json', 'requirements.txt')
@@ -171,7 +174,8 @@ def _parse_input_workspace_name(ctx, param, value):
               default=DEFAULT_LOCATION,
               required=False, type=str,
               help='Azure location (default: %s)' % DEFAULT_LOCATION)
-def init_project(path, name, subscription_id, resource_group,
+@click.pass_context
+def init_project(ctx, path, name, subscription_id, resource_group,
                  workspace_name, location):
     """
     Create a new, empty machine learning project.
@@ -179,7 +183,7 @@ def init_project(path, name, subscription_id, resource_group,
     if not os.path.isdir(path):
         os.makedirs(path)
 
-    Project.create(
+    project = Project.create(
         path=path,
         name=name,
         subscription_id=subscription_id,
@@ -192,3 +196,9 @@ def init_project(path, name, subscription_id, resource_group,
     click.echo('Initialized the project at: %s' % path)
     click.echo('Type "%s model init" to add a new model to the project.'
                % COMMAND_NAME)
+    click.echo('-' * 79)
+
+    if click.confirm('Would you like a .gitignore added to your project?', default=True):  # noqa: E501
+        ctx.invoke(add_gitignore_lines, project=project)
+    if click.confirm('Would you like Azure DevOps Pipelines added to your project?', default=True):  # noqa: E501
+        ctx.invoke(add_pipeline_files, project=project)
